@@ -35,3 +35,6 @@ FACEBOOK_APPLICATION_DOMAIN = getattr(settings, 'FACEBOOK_APPLICATION_DOMAIN', '
 
 # A boolean describing whether to cache the signed request.
 FANDJANGO_CACHE_SIGNED_REQUEST = getattr(settings, 'FACEBOOK_SIGNED_REQUEST_COOKIE', True)
+
+# A string describing the website URL.
+FANDJANGO_SITE_URL = getattr(settings, 'FANDJANGO_SITE_URL')
